@@ -6,10 +6,10 @@
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 from .columns import create_columns, drop_columns
+from .defs import get_trigger_name, get_function_name, When, Operation
 from .extract_columns import extract_columns, get_column_to_dependency_columns
 from .main import upgrade, finalize, downgrade
 from .migrate_data import update_table_data
-from .naming import get_trigger_name, get_function_name
 from .reflection import get_table_columns, check_columns_exist
 from .trigger import create_triggers, drop_triggers, create_update_trigger, create_insert_trigger
 from .utils import apply_prefix
